#
# spec file for package orthanc-dicomweb
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019-2020 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           orthanc-dicomweb
Summary:        WebViewer plugin for Orthanc
License:        AGPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
Version:        1.2
Release:        lp152.1.1
URL:            https://orthanc-server.com
Source0:        https://www.orthanc-server.com/downloads/get.php?path=/plugin-dicom-web/OrthancDicomWeb-%{version}.tar.gz
Source1:        cornerstone.css
Source2:        cornerstone.min.js
Source3:        bootstrap-4.3.1.zip
Source4:        Font-Awesome-4.7.0.tar.gz
Source5:        axios-0.19.0.tar.gz
Source6:        vuejs-2.6.10.tar.gz
Source7:        bootstrap-vue-2.0.0-rc.24-dist.tar.gz
Source8:        babel-polyfill-6.26.0.min.js.gz
Source9:        orthanc-dicomweb-readme.SUSE
Source10:       dicomweb.json

BuildRequires:  cmake
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc-c++
BuildRequires:  googletest-devel
BuildRequires:  jsoncpp-devel
BuildRequires:  libboost_date_time-devel >= 1.66
BuildRequires:  libboost_filesystem-devel >= 1.66
BuildRequires:  libboost_locale-devel >= 1.66
BuildRequires:  libboost_regex-devel >= 1.66
BuildRequires:  libboost_system-devel >= 1.66
BuildRequires:  libboost_thread-devel >= 1.66
BuildRequires:  openssl-devel
BuildRequires:  orthanc-devel
BuildRequires:  orthanc-source
BuildRequires:  pugixml-devel
BuildRequires:  unzip
BuildRequires:  uuid-devel

Requires:       orthanc

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
WebViewer plugin for Orthanc

%prep
%setup -q -n OrthancDicomWeb-%{version}

#OrthanPlugins may ask for additional files to be loaded
#Putting them into this folder prevents download of sources from the web
mkdir ThirdPartyDownloads
cd ThirdPartyDownloads
cp %{S:1} %{S:2} %{S:3} %{S:4} %{S:5} %{S:6} %{S:7} %{S:8}  .
cd ..

%build

%cmake ../ \
       -DALLOW_DOWNLOADS=OFF \
       -DUSE_SYSTEM_GOOGLE_TEST=ON \
       -DUSE_SYSTEM_ORTHANC_SDK=ON \
       -DORTHANC_FRAMEWORK_SOURCE=path \
       -DBoost_NO_BOOST_CMAKE=ON \
       -DORTHANC_FRAMEWORK_ROOT=/usr/src/orthanc/ \
       -DLIB_INSTALL_DIR=%{_libdir}/share/orthanc/plugins/

%cmake_build %{?_smp_mflags}

%install

mkdir -p -m 755 %{buildroot}%{_docdir}/orthanc

%cmake_install

# architecture dependent files should not be in /usr/share... 
# create a directory

mkdir -p -m 755 %{buildroot}%{_libdir}/share/orthanc/plugins

mv %{buildroot}%{_prefix}/share/orthanc/plugins/*.so* %{buildroot}%{_libdir}/share/orthanc/plugins/.

#orthanc expects the libs in the plugin-directory

ln -s ../../../..%{_libdir}/share/orthanc/plugins/libOrthancDicomWeb.so.%{version} \
      %{buildroot}%{_prefix}/share/orthanc/plugins/libOrthancDicomWeb.so

rm %{buildroot}%{_libdir}/share/orthanc/plugins/libOrthancDicomWeb.so

cp %{S:1} %{S:9} %{S:10} %{buildroot}%{_docdir}/orthanc/.

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%license COPYING
%dir %{_docdir}/orthanc
%{_docdir}/orthanc/*
%dir %{_libdir}/share
%dir %{_libdir}/share/orthanc
%dir %{_libdir}/share/orthanc/plugins
%{_libdir}/share/orthanc/plugins/*.so*
%dir %{_prefix}/share/orthanc
%dir %{_prefix}/share/orthanc/plugins
%{_prefix}/share/orthanc/plugins/*.so*

%changelog
* Wed May 27 2020 Axel Braun <axel.braun@gmx.de>
- version 1.2
  * requires orthanc 1.7
  * Removed dependency on GDCM
  * "QidoCaseSensitive" defaults to "CaseSensitivePN" of Orthanc configuration (instead of "true")
* Thu Mar  5 2020 Axel Braun <axel.braun@gmx.de>
- Version 1.1
  * Support of "window", "viewport" and "quality" parameters in "Retrieve Rendered Transaction"
  * Support of "/studies/.../rendered" and "/studies/.../series/.../rendered"
  * QIDO-RS: Allow to query against a list of multiple values separated by commas
  * WADO-RS "Retrieve Metadata": Configuration options "StudiesMetadata"
  and "SeriesMetadata", whose value can be "Full" (read all DICOM
  instances from the storage area), "MainDicomTags" (only report the
  main DICOM tags from the Orthanc database), or "Extrapolate" (main
  DICOM tags + user-specified tags extrapolated from a few random instances)
  * QIDO-RS: Optimization for large studies/series
  * QIDO-RS: Fix returned attributes if Study/Series Instance UIDs are not filtered
  * Fix handling of the "Forwarded" HTTP header
  * Fix support for client certificate authentication
  * Accept multiple MIME types in Accept header for WADO-RS "Retrieve Metadata"
  https://groups.google.com/d/msg/orthanc-users/P3B6J9abZpE/syn5dnW2AwAJ
  * Added explicit "Accept" header to avoid uncompressing DICOM files by Google cloud,
  can be turned off by setting "HasWadoRsUniversalTransferSyntax" to "false" (for
  instance if contacting a remote Orthanc plugin with DICOMweb version <= 1.0)
  https://groups.google.com/d/msg/orthanc-users/w1Ekrsc6-U8/T2a_DoQ5CwAJ
  * Fix issue #162 ("DICOMweb metadata resource reads all instances")
  * Fix issue #164 ("JPEG YBR_422 generates a 500 in the DicomWeb plugin")
  * Upgrade to GDCM 3.0.4 in static builds
* Thu Aug  8 2019 Axel Braun <axel.braun@gmx.de>
- Version 1.0
  initial build on OBS
